pub enum OrganizationUserStatusType {
Invited,
Accepted,
Confirmed,
Staged,
Revoked,
__Unknown(i64),
}Expand description
OrganizationUserStatusType : Represents the different stages of a member’s lifecycle in an organization. The Bit.Core.Entities.OrganizationUser object is populated differently depending on their Status. Represents the different stages of a member’s lifecycle in an organization. The Bit.Core.Entities.OrganizationUser object is populated differently depending on their Status.
Variants
Invited
Accepted
Confirmed
Staged
Revoked
__Unknown(i64)
Unknown value returned from the server. This is used to handle forward compatibility.
Implementations